@@ -373,13 +373,13 @@ class Polymer:
         else:
             return None
 
-    def getMoleculeList(self, experimentalMass: float = None, ppmDev: float = 5, resolution: float = None):
+    def getMoleculeList(self, experimentalMass: float = None, ppmDev: float = 5, resolution: float = None, absoluteDev: bool = False):
         if experimentalMass is None:
             return [[index, list(macromolecule["repUnitsCombination"]), None] for index, macromolecule in enumerate(self.macromolecules)]
         moleculeList = []
         isotopicDist = self.getIsotopicDist_indexed(resolution)
-        deviation = abs((experimentalMass - isotopicDist[:, 1]) / isotopicDist[:, 1] * 1e6)
-        in_limit = np.where(deviation <= ppmDev)
+        deviation = experimentalMass - isotopicDist[:, 1] if absoluteDev else abs((experimentalMass - isotopicDist[:, 1]) / isotopicDist[:, 1] * 1e6)
+        in_limit = np.where(abs(deviation / isotopicDist[:, 1] * 1e6) <= ppmDev) if absoluteDev else np.where(deviation <= ppmDev)
         isotopicDist = np.append(isotopicDist[in_limit], np.reshape(deviation, (-1, 1))[in_limit], axis=1)
         for index in np.unique(isotopicDist[:, 0]):
             moleculeList.append([int(index),
