@@ -154,7 +154,7 @@ class Spectrum:
         else:
             return False
 
-    def matchPeaks(self, polymerSimulation):
+    def matchPeaks(self, polymerSimulation, absoluteDev: bool = False):
         self.polymerSimulation = polymerSimulation
 
         print("Matching experimental spectrum to peaks of the simulated polymer...")
@@ -182,7 +182,7 @@ class Spectrum:
         print("--> Matching...")
         sys.stdout.flush()
         for mz, relAbundance in progressbar.progressbar(self.peakData.itertuples(index=False, name=None), 0, len(self.peakData)):
-            moleculeList = self.polymerSimulation.getMoleculeList(mz, self.ppmDev, self.resolution)
+            moleculeList = self.polymerSimulation.getMoleculeList(mz, self.ppmDev, self.resolution, absoluteDev)
             if moleculeList is not None:
                 macromolecules = []
                 normAbundances = []
